use bare_metrics_core::structures::MetricKind;
use serde::Deserialize;
use std::collections::BTreeMap;

#[derive(Deserialize, Default, Clone)]
pub struct DashboardConfig {
    pub graphs: Vec<GraphConfig>,
}

#[derive(Deserialize, Clone, Debug, Hash, Eq, PartialEq)]
pub enum MetricTransform {
    Rate {
        // Divisor in seconds. Would usually expect to see 1 (/sec), 60 (/min) or 3600 (/hour).
        time_unit: u32,
    },
}

#[derive(Deserialize, Clone)]
pub struct GraphConfig {
    pub name: String,
    pub kind: MetricKind,
    #[serde(default)]
    pub transform: Option<MetricTransform>,
    #[serde(default)]
    pub rendering: GraphRenderingHints,
}

#[derive(Clone, Debug, Hash, Eq, PartialEq)]
pub struct GraphRequest {
    pub metric_name: String,
    pub metric_labels: BTreeMap<String, String>,
    pub derivation: Option<MetricTransform>,
}

#[derive(Clone, Debug, Default, Deserialize)]
pub struct GraphRenderingHints {
    /// The view will be forced to include this range.
    pub include_y_range: Option<(f64, f64)>,
}
